@@ -13,7 +13,8 @@ class LineUIApp:
         self.line_size = 11
         self.console_height = 5
         self.console_lines = []
-        self.sched_count = -1
+        self.sched_counts = []
+        self.sched_handlers = []
         self.mod = None
 
     def print(self, x):
@@ -65,16 +66,24 @@ class LineUIApp:
                 self.key = k
                 self.call_handler("on_key")
             n += 1
-            if n == LineUIApp.FRAMES_PER_SECOND:
+            if n==LineUIApp.FRAMES_PER_SECOND:
                 self.call_handler("on_second")
-                n = 0
-            if self.sched_count >= 0:
-                if self.sched_count == 0:
-                    self.call_handler(self.sched_handler_name)
-                self.sched_count -= 1
+                n=0
+            self.check_sched_handlers()
             self.call_handler("on_update")
             sleep(1 / LineUIApp.FRAMES_PER_SECOND)
 
+    def check_sched_handlers(self):
+        i=0
+        while i<len(self.sched_counts):
+            self.sched_counts[i]-=1
+            if self.sched_counts[i] == 0:
+                self.sched_counts.pop(i)
+                h=self.sched_handlers.pop(i)
+                self.call_handler(h)
+            else:
+                i+=1
+
     def call_handler(self, handler_name):
         if isinstance(handler_name, str):
             h = self.mod.get(handler_name)
@@ -86,18 +95,21 @@ class LineUIApp:
             h()
 
     def schedule(self, seconds, handler_name):
-        if self.sched_count > 0:
-            raise RuntimeError("At most one task can be scheduled")
-        self.sched_count = int(seconds*LineUIApp.FRAMES_PER_SECOND)
-        self.sched_handler_name = handler_name
+        if len(self.sched_counts) > 5:
+            raise RuntimeError("At most five tasks can be scheduled")
+        self.sched_counts.append(int(seconds*LineUIApp.FRAMES_PER_SECOND))
+        self.sched_handlers.append(handler_name)
 
     def stop(self):
         self.done = True
 
-    def draw_at(self, x, s, erase=True):
-        if erase:
-            self.line_pane_c.erase()
-            self.line_pane_c.refresh()
+    def erase(self):
+        self.line_pane_c.erase()
+        self.line_pane_c.refresh()
+
+    def draw_at(self, x, s):
+        if type(s)!=str:
+            raise ValueError(f"{s} is not a str")
         if x < 0:
             d = -x
             x = 0
@@ -113,11 +125,11 @@ class LineUIApp:
         LineUIApp.safe_addstr(self.line_pane_c, 0, x, s)
         self.line_pane_c.refresh()
 
-    def draw_r(self, s, erase=True):
-        self.draw_at(self.line_size - len(s), s, erase)
+    def draw_r(self, s):
+        self.draw_at(self.line_size - len(s), s)
 
-    def draw_m(self, s, erase=True):
-        self.draw_at(int((self.line_size - len(s)) / 2), s, erase)
+    def draw_m(self, s):
+        self.draw_at(int((self.line_size - len(s)) / 2), s)
 
     def safe_get_key(self):
         try:
@@ -131,31 +143,27 @@ class LineUIApp:
 
 line_ui_app = LineUIApp()
 
+def draw(s):
+    draw_l(s)
 
-def draw(s, erase=True):
-    draw_l(s, erase)
+def draw_at(x, s):
+    line_ui_app.draw_at(x, s)
 
+def draw_l(s):
+    line_ui_app.draw_at(0, s)
 
-def draw_at(x, s, erase=True):
-    line_ui_app.draw_at(x, s, erase)
+def draw_r(s):
+    line_ui_app.draw_r(s)
 
+def draw_m(s):
+    line_ui_app.draw_m(s)
 
-def draw_l(s, erase=True):
-    line_ui_app.draw_at(0, s, erase)
-
-
-def draw_r(s, erase=True):
-    line_ui_app.draw_r(s, erase)
-
-
-def draw_m(s, erase=True):
-    line_ui_app.draw_m(s, erase)
-
+def erase():
+    line_ui_app.erase()
 
 def get_key():
     return line_ui_app.key
 
-
 def print(x):
     line_ui_app.print(x)
 
@@ -172,6 +180,7 @@ def stop():
     line_ui_app.stop()
 
 
-def start(mod):
-    line_ui_app.mod = mod
+def start(mod=None):
+    import __main__
+    line_ui_app.mod = vars(__main__)
     wrapper(line_ui_app.main_loop)
